@@ -51,7 +51,10 @@ pub fn spawn_app_validation_consumer(
             )
             .await;
             match result {
-                Ok(WorkComplete::Incomplete) => trigger_self.trigger(),
+                Ok(WorkComplete::Incomplete) => {
+                    tracing::debug!("Work incomplete, retriggering workflow");
+                    trigger_self.trigger(&"retrigger")
+                }
                 Err(err) => handle_workflow_error(err)?,
                 _ => (),
             };
