@@ -379,7 +379,7 @@ async fn get_agent_activity_test() {
     // Commit private messages
     commit_some_data("create_priv_msg", &alice_call_data, &handle).await;
 
-    alice_call_data.triggers.produce_dht_ops.trigger();
+    alice_call_data.triggers.produce_dht_ops.trigger(&"");
 
     expected_count += NUM_COMMITS * 2;
     wait_for_integration(
@@ -426,7 +426,7 @@ async fn get_agent_activity_test() {
         .clone();
 
     // Wait for alice to integrate the chain as an authority
-    alice_call_data.triggers.produce_dht_ops.trigger();
+    alice_call_data.triggers.produce_dht_ops.trigger(&"");
     expected_count += NUM_COMMITS * 3;
     wait_for_integration(
         &alice_call_data.db,
