@@ -84,8 +84,8 @@ where
                     }
                 }
                 None => {
-                    trigger_publish_dht_ops.trigger();
-                    trigger_integrate_dht_ops.trigger();
+                    trigger_publish_dht_ops.trigger(&"trigger_publish_dht_ops");
+                    trigger_integrate_dht_ops.trigger(&"trigger_integrate_dht_ops");
                 }
             }
         }
