@@ -115,6 +115,7 @@ mod tests {
     use holochain_p2p::actor::HolochainP2pSender;
     use holochain_p2p::HolochainP2pDna;
     use holochain_p2p::HolochainP2pRef;
+    use holochain_types::db_cache::DhtDbQueryCache;
     use observability;
     use rusqlite::Transaction;
     use std::collections::HashMap;
@@ -405,6 +406,7 @@ mod tests {
                 let source_chain = SourceChain::new(
                     db.clone().into(),
                     dht_db.to_db(),
+                    DhtDbQueryCache::new(dht_db.clone().into()),
                     keystore.clone(),
                     author.clone(),
                 )
@@ -462,8 +464,7 @@ mod tests {
                 let expected = {
                     let mut map = HashMap::new();
                     // Op is expected to not contain the Entry even though the above contains the entry
-                    let (entry_create_header, sig) =
-                        entry_create_header.into_header_and_signature();
+                    let (entry_create_header, sig) = entry_create_header.into_inner();
                     let expected_op = DhtOp::RegisterAgentActivity(
                         sig.clone(),
                         entry_create_header.clone().into_content(),
@@ -485,8 +486,7 @@ mod tests {
 
                     // Create RegisterUpdatedContent
                     // Op is expected to not contain the Entry
-                    let (entry_update_header, sig) =
-                        entry_update_header.into_header_and_signature();
+                    let (entry_update_header, sig) = entry_update_header.into_inner();
                     let entry_update_header: Update =
                         entry_update_header.into_content().try_into().unwrap();
                     let expected_op =
