@@ -16,6 +16,7 @@ use holochain_p2p::actor::HolochainP2pRefToDna;
 use holochain_p2p::HolochainP2pDna;
 use holochain_serialized_bytes::SerializedBytes;
 use holochain_state::prelude::test_db_dir;
+use holochain_types::db_cache::DhtDbQueryCache;
 use holochain_types::prelude::*;
 use holochain_wasm_test_utils::TestWasm;
 use kitsune_p2p::KitsuneP2pConfig;
@@ -29,6 +30,7 @@ pub struct CellHostFnCaller {
     pub cell_id: CellId,
     pub authored_db: DbWrite<DbKindAuthored>,
     pub dht_db: DbWrite<DbKindDht>,
+    pub dht_db_cache: DhtDbQueryCache,
     pub cache: DbWrite<DbKindCache>,
     pub ribosome: RealRibosome,
     pub network: HolochainP2pDna,
@@ -42,6 +44,7 @@ impl CellHostFnCaller {
     pub async fn new(cell_id: &CellId, handle: &ConductorHandle, dna_file: &DnaFile) -> Self {
         let authored_db = handle.get_authored_db(cell_id.dna_hash()).unwrap();
         let dht_db = handle.get_dht_db(cell_id.dna_hash()).unwrap();
+        let dht_db_cache = handle.get_dht_db_cache(cell_id.dna_hash()).unwrap();
         let cache = handle.get_cache_db(cell_id).unwrap();
         let keystore = handle.keystore().clone();
         let network = handle.holochain_p2p().to_dna(cell_id.dna_hash().clone());
@@ -54,6 +57,7 @@ impl CellHostFnCaller {
             cell_id: cell_id.clone(),
             authored_db,
             dht_db,
+            dht_db_cache,
             cache,
             ribosome,
             network,
@@ -72,6 +76,7 @@ impl CellHostFnCaller {
         HostFnCaller {
             authored_db: self.authored_db.clone(),
             dht_db: self.dht_db.clone(),
+            dht_db_cache: self.dht_db_cache.clone(),
             cache: self.cache.clone(),
             ribosome: self.ribosome.clone(),
             zome_path,
@@ -84,7 +89,7 @@ impl CellHostFnCaller {
 }
 
 /// Everything you need to run a test that uses the conductor
-// TODO: rewrite as sweettests if possible
+// MAYBE: rewrite as sweettests if possible
 pub struct ConductorTestData {
     _db_dir: TempDir,
     handle: ConductorHandle,
